Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(201)

Unified Diff: webkit/tools/test_shell/test_shell_request_context.h

Issue 6338002: net: Remove typedef net::URLRequestContext URLRequestContext; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: for real Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/tools/test_shell/test_shell_request_context.h
diff --git a/webkit/tools/test_shell/test_shell_request_context.h b/webkit/tools/test_shell/test_shell_request_context.h
index 4baebc310d3a62b4b3be1793b0e43cddb1b5266f..ff88d8e22d9fe24fa8f6967f9f69e0b0631c4268 100644
--- a/webkit/tools/test_shell/test_shell_request_context.h
+++ b/webkit/tools/test_shell/test_shell_request_context.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -15,8 +15,8 @@ namespace webkit_blob {
class BlobStorageController;
}
-// A basic URLRequestContext that only provides an in-memory cookie store.
-class TestShellRequestContext : public URLRequestContext {
+// A basic net::URLRequestContext that only provides an in-memory cookie store.
+class TestShellRequestContext : public net::URLRequestContext {
public:
// Use an in-memory cache
TestShellRequestContext();

Powered by Google App Engine
This is Rietveld 408576698